/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.user;

import org.onosproject.nemo.model.common.UserId;
import org.onosproject.nemo.model.common.UserName;
import org.onosproject.nemo.model.common.UserPassword;
import org.onosproject.nemo.model.common.UserRoleName;

/**
 * User instance which contains user information.
 */
public interface UserInstance {

    /**
     * Returns the unique ID for a user.
     *
     * @return user id object
     */
    UserId getUserId();

    /**
     * Returns the user-visible and unique name for a user.
     *
     * @return user
     */
    UserName getUserName();

    /**
     * Returns the password of a user.
     *
     * @return user password
     */
    UserPassword getUserPassword();

    /**
     * Returns the role of a user.
     *
     * @return user role name
     */
    UserRoleName getUserRole();
}