/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.operation;

import static org.junit.Assert.assertEquals;

import java.util.ArrayList;
import java.util.List;

import org.junit.Test;
import org.onosproject.nemo.model.common.ActionName;
import org.onosproject.nemo.model.operation.action.definitions.ActionDefinition;
import org.onosproject.nemo.model.operation.action.definitions.ActionDefinitionBuilder;

import com.google.common.testing.EqualsTester;

/**
 * Unit tests for {@link ActionDefinitionsBuilder}.
 */
public class ActionDefinitionsBuilderTest {

    private static final String DEFINITIONS_ERROR_MSG = "definitions not set";
    private static final String NAME = "SomeName";
    private static final String OTHER_NAME = "OtherName";

    private List<ActionDefinition> definitionList;
    private List<ActionDefinition> otherList;
    private ActionDefinitions definitions;
    private ActionDefinitions copy;
    private ActionDefinitions diff;
    private ActionName name;
    private ActionName otherName;
    private ActionDefinition definition;
    private ActionDefinition otherDefinition;

    @Test
    public void buildActionDefinitionWithActionDefinitions() {
        definitionList = new ArrayList<>();
        definitions = new ActionDefinitionsBuilder()
                .actionDefinitions(definitionList)
                .build();
        assertEquals(DEFINITIONS_ERROR_MSG, definitionList,
                definitions.getActionDefinitions());
    }

    @Test
    public void fromActionDefinitionWithActionDefinitions() {
        definitionList = new ArrayList<>();
        definitions = new ActionDefinitionsBuilder()
                .actionDefinitions(definitionList)
                .build();
        copy = new ActionDefinitionsBuilder(definitions).build();
        assertEquals(DEFINITIONS_ERROR_MSG, definitionList,
                copy.getActionDefinitions());
    }

    @Test
    public void equality() {
        definitionList = new ArrayList<>();
        definitions = new ActionDefinitionsBuilder()
                .actionDefinitions(definitionList)
                .build();
        otherList = new ArrayList<>();
        otherList.add(null);
        copy = new ActionDefinitionsBuilder()
                .actionDefinitions(definitionList)
                .build();
        diff = new ActionDefinitionsBuilder()
                .actionDefinitions(otherList)
                .build();
        new EqualsTester()
                .addEqualityGroup(definitions, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }

    @Test
    public void equalityTwo() {
        name = new ActionName(NAME);
        otherName = new ActionName(OTHER_NAME);
        definition = new ActionDefinitionBuilder()
                .actionName(name)
                .build();
        definitionList = new ArrayList<>();
        definitionList.add(definition);
        definitions = new ActionDefinitionsBuilder()
                .actionDefinitions(definitionList)
                .build();
        otherList = new ArrayList<>();
        otherDefinition = new ActionDefinitionBuilder()
                .actionName(otherName)
                .build();
        otherList.add(otherDefinition);
        copy = new ActionDefinitionsBuilder()
                .actionDefinitions(definitionList)
                .build();
        diff = new ActionDefinitionsBuilder()
                .actionDefinitions(otherList)
                .build();
        new EqualsTester()
                .addEqualityGroup(definitions, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }
}